/*
 * PJAFontConfiguration.java
 *
 * Copyright (c) 2000-2008 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.eteks.java2d;

import java.nio.charset.Charset;

import sun.awt.FontConfiguration;
import sun.font.CompositeFontDescriptor;
import sun.java2d.SunGraphicsEnvironment;

/**
 * Pure Java AWT FontConfiguration implementation (thanks to Llorenc Sabat).
 * 
 * @version 2.6
 * @author Emmanuel Puybaret
 * @see com.eteks.java2d.PJAGraphicsEnvironment
 * @since PJA2.6
 */
public class PJAFontConfiguration extends FontConfiguration
{
  public PJAFontConfiguration(SunGraphicsEnvironment environment)
  {
    super(environment);
  }

  public PJAFontConfiguration(SunGraphicsEnvironment environment,
      boolean preferLocaleFonts, boolean preferPropFonts)
  {
    super(environment, preferLocaleFonts, preferPropFonts);
  }

  public String[] getPlatformFontNames()
  {
    // Return an empty array and let GraphicsEnvironment register its fonts
    return new String[0];
  }

  public int getNumberCoreFonts()
  {
    // Return 0 and let GraphicsEnvironment register its fonts
    return 0;
  }

  public CompositeFontDescriptor[] get2DCompositeFontInfo()
  {
    // Return an empty array and let SWTGraphicsEnvironment register its fonts
    return new CompositeFontDescriptor[0];
  }

  public String getFallbackFamilyName(String fontName, String defaultFallback)
  {
    // Return compatibility fallback name and let GraphicsEnvironment register
    // these fonts
    String compatibilityName = getCompatibilityFamilyName(fontName);
    if (compatibilityName != null)
    {
      return compatibilityName;
    }
    return defaultFallback;
  }

  protected String getFileNameFromComponentFontName(String componentFontName)
  {
    return getFileNameFromPlatformName(componentFontName);
  }

  public String getFaceNameFromComponentFontName(String componentFontName)
  {
    return componentFontName;
  }

  protected String getEncoding(String awtFontName, String characterSubsetName)
  {
    return "default";
  }

  protected void initReorderMap()
  {
  }

  protected Charset getDefaultFontCharset(String arg0)
  {
    return null;
  }
}
